import ExperimentSDK from '../ExperimentSDK';
import { GetAssignmentOptions, SDKAssignment, TypeData } from '../types';
/**
 * Valid values to represent the lifecycle of a hook with an async call.
 * "null" is the default status when a hook is initialized
 */
export declare enum HookAsyncStatus {
    LOADING = "LOADING",
    SUCCESS = "SUCCESS",
    ERROR = "ERROR"
}
/**
 * Context values.
 */
export interface ExperimentSDKContextType<T extends TypeData> {
    /**
     * An instance of the {@link ExperimentSDK}. "null" by default.
     */
    sdkInstance: ExperimentSDK<T> | null;
}
/**
 * Context provider properties.
 * Takes in {@link ExperimentSDKContextType} values, plus the React "children" property
 */
export type ExperimentSDKProviderProps<T extends TypeData> = React.PropsWithChildren<ExperimentSDKContextType<T>>;
/**
 * Config object passed into the {@link useTrackIsInSample} hook.
 */
export interface UseTrackIsInSampleConfig<ExperimentViewedProps, LoggerTeam> {
    experimentName: string;
    shouldFireEvent?: boolean;
    customProperties?: ExperimentViewedProps;
    team?: LoggerTeam;
}
/**
 * Additional options the useAssignment hook can take beyond the {@link GetAssignmentOptions} options.
 */
export interface UseAssignmentOptions<T extends TypeData> extends GetAssignmentOptions<T> {
    /**
     * An optional array of {@link BasicHookResponse} objects that should trigger a refetch of assignments.
     * For example, if you want to refetch assignments after a "useAssign" call is complete, you can pass
     * the return value of "useAssign" in this array.
     */
    hookDependencies?: Array<BasicHookResponse>;
}
/**
 * A standard response object from a hook with async calls.
 */
export interface BasicHookResponse {
    asyncStatus: HookAsyncStatus | null;
    error: Error | null;
}
/**
 * Additional response props of the {@link useAssignment} hook.
 */
export interface UseAssignmentResponse<T extends TypeData> extends BasicHookResponse {
    assignment: SDKAssignment<T['experimentName'], T['experimentVariantName']> | null;
}
//# sourceMappingURL=types.d.ts.map