import ExperimentSDK from '../ExperimentSDK';
import { TypeData } from '../types';
export declare const LOG_PREFIX = "Experiment SDK - React: ";
export declare const ERRORS: {
    ROOT_SDK_MUST_BE_INITIALIZED: string;
};
/**
 * A utility function that checks for the presence of {@link ExperimentSDK}. If it's null,
 * throw an error.
 *
 * Useful in the hook functions to confirm SDK presence before proceeding.
 */
export declare function checkForSdk<T extends TypeData>(sdk: ExperimentSDK<T> | null): asserts sdk is ExperimentSDK<T>;
/**
 * @description
 * Pulls the instance of the SDK from context, and throws an error if it's not present.
 * This is intended for internal use only. In almost every case, one of the provided hooks
 * (e.g. useExperimentAttribute, useTrackIsInSample) will be safer and more resilient to change
 * than trying to access the SDK directly from inside React.
 *
 * Note: This hook is typed as a generic so that you can provide your TypeData configuration,
 * but nothing is actually checking that that type matches the one given to the ExperimentSDKProvider.
 * Lie to TypeScript at your own risk!
 *
 * @return The instance of the SDK in context
 *
 * @example
 * ```ts
  const sdk = useSDKInstance<ExpTypes>();

  useEffect(() => {
    // NOTE: Don't do this in app code, call useTrackIsInSample instead
    sdk.trackIsInSample()
  }, [sdk]);
 ```
 */
export declare function useSDKInstance<T extends TypeData>(): ExperimentSDK<T>;
//# sourceMappingURL=utils.d.ts.map